package com.muyu.web.config.properties;

import com.muyu.web.domain.model.ServerConfigModel;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @Author: DongZeLiang
 * @date: 2024/6/10
 * @Description: 服务器配置类
 * @Version: 1.0
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class ServiceConfigProperties {

    /**
     * 主机地址
     */
    private String host;
    /**
     * 端口号
     */
    private String port;
    /**
     * 负载地址
     */
    private String loadUrl;
    /**
     * 负载请求格式化地址
     */
    private String loadReqUrl;
    /**
     * 默认MQTT地址
     */
    private String mqttAddr;
    /**
     * 默认MQTT主题
     */
    private String mqttTopic;
    /**
     * 默认MQTT交付级别
     */
    private Integer mqttQos;

    /**
     * 模型构建配置
     * @param serverConfigModel 配置模型对象
     * @return 配置对象
     */
    public ServiceConfigProperties modelToProperties(ServerConfigModel serverConfigModel) {
        this.host = serverConfigModel.getHost();
        this.port = serverConfigModel.getPort();
        this.loadUrl = serverConfigModel.getLoadUrl();
        this.mqttAddr = serverConfigModel.getDefaultMqttAddr();
        this.mqttTopic = serverConfigModel.getDefaultMqttTopic();
        this.mqttQos = serverConfigModel.getDefaultMqttQos();
        this.loadReqUrl = String.format("http://%s:%s%s", host, port, loadUrl.startsWith("/") ? loadUrl : "/" + loadUrl);
        return this;
    }

}
